==> hs-fgl-5.4.2.3_2.tbz: lib/ghc-7.0.3/cabal/fgl-5.4.2.3/register.sh <==
#!/bin/sh
echo 'name: fgl
version: 5.4.2.3
id: fgl-5.4.2.3-3f764e9cf21f2550b9fec3a3ceab534a

license: BSD3
copyright:
maintainer: Ivan.Miljenovic@gmail.com, tomberek@gmail.com
stability:
homepage: http://web.engr.oregonstate.edu/~erwig/fgl/haskell
package-url:
description:
category: Data Structures
author: Martin Erwig, Ivan Lazar Miljenovic
exposed: True
exposed-modules: Data.Graph.Inductive.Internal.FiniteMap
                 Data.Graph.Inductive.Internal.Heap
                 Data.Graph.Inductive.Internal.Queue
                 Data.Graph.Inductive.Internal.RootPath
                 Data.Graph.Inductive.Internal.Thread Data.Graph.Inductive.Basic
                 Data.Graph.Inductive.Example Data.Graph.Inductive.Graph
                 Data.Graph.Inductive.Graphviz Data.Graph.Inductive.Monad
                 Data.Graph.Inductive.NodeMap Data.Graph.Inductive.PatriciaTree
                 Data.Graph.Inductive.Query Data.Graph.Inductive.Tree
                 Data.Graph.Inductive.Monad.IOArray
                 Data.Graph.Inductive.Query.ArtPoint Data.Graph.Inductive.Query.BCC
                 Data.Graph.Inductive.Query.BFS Data.Graph.Inductive.Query.DFS
                 Data.Graph.Inductive.Query.Dominators
                 Data.Graph.Inductive.Query.GVD Data.Graph.Inductive.Query.Indep
                 Data.Graph.Inductive.Query.MST Data.Graph.Inductive.Query.MaxFlow
                 Data.Graph.Inductive.Query.MaxFlow2
                 Data.Graph.Inductive.Query.Monad Data.Graph.Inductive.Query.SP
                 Data.Graph.Inductive.Query.TransClos Data.Graph.Inductive
hidden-modules:
import-dirs: /usr/local/lib/ghc-7.0.3/cabal/fgl-5.4.2.3
library-dirs: /usr/local/lib/ghc-7.0.3/cabal/fgl-5.4.2.3
              /usr/local/lib
hs-libraries: HSfgl-5.4.2.3
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: array-0.3.0.2-3444ee049e55c8df31a0796287f56a5e
         base-4.3.1.0-63fd52d9e7e39016c91be0baf3543757
         containers-0.4.0.0-8781485edb2ac0db733a9f9c72e27945
         mtl-2.0.1.0-91f62d81c946aa60137dcc008e554a3a
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.3/cabal/fgl-5.4.2.3/html/fgl.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.3/cabal/fgl-5.4.2.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-fgl-5.4.2.4_4.tbz: lib/ghc-7.4.2/cabal/fgl-5.4.2.4/register.sh <==
#!/bin/sh
echo 'name: fgl
version: 5.4.2.4
id: fgl-5.4.2.4-7c03998a8b5741b6ab1e7be146250933

license: BSD3
copyright:
maintainer: Ivan.Miljenovic@gmail.com, tomberek@gmail.com
stability:
homepage: http://web.engr.oregonstate.edu/~erwig/fgl/haskell
package-url:
synopsis: Martin Erwig'\''s Functional Graph Library
description:
category: Data Structures, Graphs
author: Martin Erwig, Ivan Lazar Miljenovic
exposed: True
exposed-modules: Data.Graph.Inductive.Internal.FiniteMap
                 Data.Graph.Inductive.Internal.Heap
                 Data.Graph.Inductive.Internal.Queue
                 Data.Graph.Inductive.Internal.RootPath
                 Data.Graph.Inductive.Internal.Thread Data.Graph.Inductive.Basic
                 Data.Graph.Inductive.Example Data.Graph.Inductive.Graph
                 Data.Graph.Inductive.Graphviz Data.Graph.Inductive.Monad
                 Data.Graph.Inductive.NodeMap Data.Graph.Inductive.PatriciaTree
                 Data.Graph.Inductive.Query Data.Graph.Inductive.Tree
                 Data.Graph.Inductive.Monad.IOArray
                 Data.Graph.Inductive.Query.ArtPoint Data.Graph.Inductive.Query.BCC
                 Data.Graph.Inductive.Query.BFS Data.Graph.Inductive.Query.DFS
                 Data.Graph.Inductive.Query.Dominators
                 Data.Graph.Inductive.Query.GVD Data.Graph.Inductive.Query.Indep
                 Data.Graph.Inductive.Query.MST Data.Graph.Inductive.Query.MaxFlow
                 Data.Graph.Inductive.Query.MaxFlow2
                 Data.Graph.Inductive.Query.Monad Data.Graph.Inductive.Query.SP
                 Data.Graph.Inductive.Query.TransClos Data.Graph.Inductive
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/fgl-5.4.2.4
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/fgl-5.4.2.4
              /usr/local/lib
hs-libraries: HSfgl-5.4.2.4
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: array-0.4.0.0-4f6c2a594155b0b953c1cf0f54040f61
         base-4.5.1.0-12fddc14a7babb909dd3843e453b5660
         containers-0.4.2.1-efa59805336a77490296ae3897cecb87
         mtl-2.1.2-cf6082d8d4c6758d23401302efadd028
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/fgl-5.4.2.4/html/fgl.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/fgl-5.4.2.4/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
